@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=missing-docstring, C0301
+import json
 import functools
-from dataskema.data_schema import DataSchema
-from flask import request
+from dataskema.data_schema import DataSchema, SchemaValidationResult
+from flask import request, make_response, Response
 
 
 class JSON(DataSchema):
@@ -15,27 +16,26 @@ class Query(DataSchema):
         super(Query, self).__init__(request.args)
 
 
-def json(**kwargs):
+def flask_json(**kwargs):
     def inner_function(function):
         @functools.wraps(function)
         def wrapper(**data):
             json_validator = JSON()
-            outdata = json_validator.check_schema(kwargs)
+            outdata = json_validator.validate(kwargs)
             outdata.update(data)
-            print("decorator json: " + str(outdata))
             return function(**outdata)
         return wrapper
     return inner_function
 
 
-def query(**kwargs):
+def flask_query(**kwargs):
     def inner_function(function):
         @functools.wraps(function)
         def wrapper(**data):
             query_validator = Query()
-            outdata = query_validator.check_schema(kwargs)
+            outdata = query_validator.validate(kwargs)
             outdata.update(data)
-            print("decorator query: " + str(outdata))
             return function(**outdata)
         return wrapper
     return inner_function
+	
\ No newline at end of file
